@@ -36,8 +36,6 @@ class DocManager(DocManagerBase):
     def __init__(self, url, auto_commit_interval=DEFAULT_COMMIT_INTERVAL,
                  unique_key='_id', chunk_size=DEFAULT_MAX_BULK, **kwargs):
         # self.graph = Graph('http://127.0.0.1:7474/db/data')
-        # self.graph = Graph('bolt://192.168.3.119:7687', auth=("neo4j", "neo4j"))
-        print(url)
         self.graph = Graph(url,auth=("neo4j", "neo4j"))
         self.auto_commit_interval = auto_commit_interval
         self.unique_key = unique_key
@@ -63,9 +61,7 @@ class DocManager(DocManagerBase):
                 ret = self.nodeExist(doubanId)
                 if ret == False:
                     if other_actor not in builder.director_list and other_actor not in builder.cast_list:
-                        print('-'*10 + doubanId)
                         cypher = statement.replace('$parameters',str(other_actor[statement]).replace("'_id'","_id").replace("'actorName'","actorName")).replace("'doubanId'","doubanId").replace("'sex'","sex")
-                        print(cypher)
                         tx.run(cypher=cypher)
                 else:
                     pass
